@@ -365,7 +365,10 @@ class BaseEnvironnement(BaseEstimator):
         if control.device.type != "cpu":
             for key, value in data.items():
                 if key not in control.expected_key_to_device:
-                    data[key] = value.to(control.device)
+                    if isinstance(data[key], (list, tuple,)):
+                        data[key] = [ii.to(control.device) for ii in data[key]]
+                    else:
+                        data[key] = value.to(control.device)
         with torch.autocast(
             device_type=control.device.type,
             enabled=control.mixed_type_gpu
@@ -422,7 +425,10 @@ class BaseEnvironnement(BaseEstimator):
         if control.device.type != "cpu":
             for key, value in data.items():
                 if key not in control.expected_key_to_device:
-                    data[key] = value.to(control.device)
+                    if isinstance(data[key], (list, tuple,)):
+                        data[key] = [ii.to(control.device) for ii in data[key]]
+                    else:
+                        data[key] = value.to(control.device)
         with torch.no_grad():
             output = self.forward(**data)
             if control.target_checktensor:
